@@ -333,14 +333,15 @@ class Seeker extends Slider.Slider {
                 this._timerTicker = 0;
                 this._getPosition();
             }
-            return true;
+            return GLib.SOURCE_CONTINUE;
         }
 
-        return false;
+        this._timeoutId = 0;
+        return GLib.SOURCE_REMOVE;
     }
 
     _updateTimer() {
-        if (this._timeoutId !== 0) {
+        if (this._timeoutId > 0) {
             Mainloop.source_remove(this._timeoutId);
             this._timeoutId = 0;
         }
@@ -403,12 +404,14 @@ class Seeker extends Slider.Slider {
     }
 
     destroy() {
-        if (this._timeoutId != 0) {
+        if (this._timeoutId > 0) {
             Mainloop.source_remove(this._timeoutId);
             this._timeoutId = 0;
         }
-        if (this._seekChangedId)
+        if (this._seekChangedId) {
             this._mediaServerPlayer.disconnectSignal(this._seekChangedId);
+            this._seekChangedId = 0;
+        }
 
         this.disconnectAll();
         this._mediaServerPlayer = null;
@@ -434,16 +437,19 @@ class StreamMenuSection extends PopupMenu.PopupMenuSection {
         }
 
         // Special cases
-        if(name === "Banshee") {
+        if (name === "Banshee") {
             iconName = "banshee";
         }
         else if (name === "Spotify") {
             iconName = "spotify";
         }
-        if(name === "VBox") {
+        else if (name === "VBox") {
             name = "Virtualbox";
             iconName = "virtualbox";
         }
+        else if (name === "Firefox") {
+            iconName = "firefox";
+        }
         else if (iconName === "audio") {
             iconName = "audio-x-generic";
         }
@@ -1101,6 +1107,7 @@ class CinnamonSoundApplet extends Applet.TextIconApplet {
             this.unregisterSystrayIcons();
         if (this._iconTimeoutId) {
             Mainloop.source_remove(this._iconTimeoutId);
+            this._iconTimeoutId = 0;
         }
 
         this._dbus.disconnectSignal(this._ownerChangedId);
@@ -1144,8 +1151,15 @@ class CinnamonSoundApplet extends Applet.TextIconApplet {
     }
 
     _onScrollEvent(actor, event) {
-        let direction = event.get_scroll_direction();
+        const direction = event.get_scroll_direction();
+
+        if (direction == Clutter.ScrollDirection.SMOOTH) {
+            return Clutter.EVENT_PROPAGATE;
+        }
+
         let currentVolume = this._output.volume;
+        let volumeChange = false;
+        let player = this._players[this._activePlayer];
 
         if (direction == Clutter.ScrollDirection.DOWN) {
             let prev_muted = this._output.is_muted;
@@ -1159,29 +1173,33 @@ class CinnamonSoundApplet extends Applet.TextIconApplet {
                 if (this._output.volume!=this._volumeNorm && this._output.volume>this._volumeNorm*(1-VOLUME_ADJUSTMENT_STEP/2) && this._output.volume<this._volumeNorm*(1+VOLUME_ADJUSTMENT_STEP/2))
                     this._output.volume=this._volumeNorm;
             }
-            this._output.push_volume();
+
+            volumeChange = true;
         }
         else if (direction == Clutter.ScrollDirection.UP) {
             this._output.volume = Math.min(this._volumeMax, currentVolume + this._volumeNorm * VOLUME_ADJUSTMENT_STEP);
             // 100% is magnetic:
             if (this._output.volume!=this._volumeNorm && this._output.volume>this._volumeNorm*(1-VOLUME_ADJUSTMENT_STEP/2) && this._output.volume<this._volumeNorm*(1+VOLUME_ADJUSTMENT_STEP/2))
                 this._output.volume=this._volumeNorm;
-            this._output.push_volume();
+
             this._output.change_is_muted(false);
+            volumeChange = true;
         }
-        else if (this.horizontalScroll) {
+        else if (this.horizontalScroll && player !== null && player._playerStatus !== "Stopped") {
             if (direction == Clutter.ScrollDirection.LEFT) {
                 this._players[this._activePlayer]._mediaServerPlayer.PreviousRemote();
             }
-            else {
+            else if (direction == Clutter.ScrollDirection.RIGHT) {
                 this._players[this._activePlayer]._mediaServerPlayer.NextRemote();
             }
         }
 
-        this._applet_tooltip.show();
-
-        if (event.get_scroll_direction() != Clutter.ScrollDirection.SMOOTH) {
+        if (volumeChange) {
+            this._output.push_volume();
             this._notifyVolumeChange(this._output);
+            this._applet_tooltip.show();
+        } else {
+            this._applet_tooltip.hide();
         }
     }
 
@@ -1191,8 +1209,9 @@ class CinnamonSoundApplet extends Applet.TextIconApplet {
         //mute or play / pause players on middle click
         if (buttonId === 2) {
             if (this.middleClickAction === "mute") {
+                if (this._output.is_muted === this._input.is_muted)
+                    this._toggle_in_mute();
                 this._toggle_out_mute();
-                this._toggle_in_mute();
             } else if (this.middleClickAction === "out_mute")
                 this._toggle_out_mute();
             else if (this.middleClickAction === "in_mute")
@@ -1212,7 +1231,7 @@ class CinnamonSoundApplet extends Applet.TextIconApplet {
     setIcon(icon, source) {
         if (this._iconTimeoutId) {
             Mainloop.source_remove(this._iconTimeoutId);
-            this._iconTimeoutId = null;
+            this._iconTimeoutId = 0;
         }
 
         //save the icon
@@ -1228,7 +1247,6 @@ class CinnamonSoundApplet extends Applet.TextIconApplet {
                 //if we have an active player, but are changing the volume, show the output icon and after three seconds change back to the player icon
                 this.set_applet_icon_symbolic_name(this._outputIcon);
                 this._iconTimeoutId = Mainloop.timeout_add_seconds(OUTPUT_ICON_SHOW_TIME_SECONDS, () => {
-                    this._iconTimeoutId = null;
                     this.setIcon();
                 });
             } else {
@@ -1278,8 +1296,9 @@ class CinnamonSoundApplet extends Applet.TextIconApplet {
             else {
                 title_text = player._title + ' - ' + player._artist;
             }
-            if (this.truncatetext < title_text.length) {
-                title_text = title_text.substr(0, this.truncatetext) + "...";
+            const glyphs = Util.splitByGlyph(title_text);
+            if (glyphs.length > this.truncatetext) {
+                title_text = glyphs.slice(0, this.truncatetext - 3).join("") + "...";
             }
         }
         this.set_applet_label(title_text);
